<?php

/**
 * @package     Joomla.Site
 * @subpackage  com_contact
 *
 * @copyright   (C) 2006 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Helper\ContentHelper;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Layout\FileLayout;
use Joomla\CMS\Layout\LayoutHelper;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Router\Route;
use Joomla\CMS\String\PunycodeHelper;
use Joomla\Component\Contact\Site\Helper\RouteHelper;

$tparams = $this->item->params;
$canDo   = ContentHelper::getActions('com_contact', 'category', $this->item->catid);
$canEdit = $canDo->get('core.edit') || ($canDo->get('core.edit.own') && $this->item->created_by === Factory::getUser()->id);
$htag    = $tparams->get('show_page_heading') ? 'h2' : 'h1';
?>

<div class="com-contact contact" itemscope itemtype="https://schema.org/Person">
    <?php if ($canEdit) : ?>
        <div class="icons">
            <div class="float-end">
                <div>
                    <?php echo HTMLHelper::_('contacticon.edit', $this->item, $tparams); ?>
                </div>
            </div>
        </div>
    <?php endif; ?>

    <div class="contact-header">
        <?php if ($this->item->image && $tparams->get('show_image')) : ?>
            <div class="author-avatar">
                <?php echo LayoutHelper::render(
                    'joomla.html.image',
                    [
                        'src'      => $this->item->image,
                        'alt'      => $this->item->name,
                        'itemprop' => 'image',
                    ]
                ); ?>
            </div>
        <?php endif; ?>
        <div class="author-info">
            <h1>
                <?php if ($this->item->published == 0) : ?>
                    <span class="badge bg-warning text-light"><?php echo Text::_('JUNPUBLISHED'); ?></span>
                <?php endif; ?>
                <span class="contact-name" itemprop="name"><?php echo $this->item->name; ?></span>
            </h1>

            <?php if ($this->item->misc && $tparams->get('show_misc')) : ?>
                <?php echo $this->item->misc; ?>
            <?php endif; ?>

            <p><a href="<?php echo $this->item->webpage; ?>" target="_blank" rel="noopener noreferrer" itemprop="url">
            <?php echo PunycodeHelper::urlToUTF8($this->item->webpage); ?></a></p>

            <?php if ($tparams->get('show_links')) : ?>
                <?php echo $this->loadTemplate('links'); ?>
            <?php endif; ?>

            <?php if ($tparams->get('show_user_custom_fields') && $this->contactUser) : ?>
                <?php echo $this->loadTemplate('user_custom_fields'); ?>
            <?php endif; ?>

        </div>
    </div>

    <?php echo $this->item->event->afterDisplayTitle; ?>
    <?php echo $this->item->event->beforeDisplayContent; ?>

    <?php if ($tparams->get('show_articles') && $this->item->user_id && $this->item->articles) : ?>
        <h2><?php echo Text::_('AUTHOR_ARTICLES'); ?></h2>

        <?php echo $this->loadTemplate('articles'); ?>
    <?php endif; ?>

    <?php echo $this->item->event->afterDisplayContent; ?>
</div>
